package cn.dg32z.lon.commands;

import cn.dg32z.libs.org.jetbrains.annotations.NotNull;
import cn.dg32z.libs.org.jetbrains.annotations.Nullable;
import cn.dg32z.lon.PluginLoader;
import java.util.ArrayList;
import java.util.List;
import java.util.Locale;
import org.bukkit.command.CommandSender;
import org.bukkit.command.TabExecutor;
import org.bukkit.entity.Player;

/* loaded from: cn_dg32z_lon_commands.jar:cn/dg32z/lon/commands/AbstractCommand.class */
public abstract class AbstractCommand implements TabExecutor, Command {
    private final String description;
    private final String permission;
    private final boolean onlyPlayer;

    public String getDescription() {
        return this.description;
    }

    public String getPermission() {
        return this.permission;
    }

    public boolean isOnlyPlayer() {
        return this.onlyPlayer;
    }

    public AbstractCommand(@NotNull String description, String permission, boolean onlyPlayer) {
        this.description = description;
        this.permission = permission;
        this.onlyPlayer = onlyPlayer;
    }

    public boolean onCommand(@NotNull CommandSender sender, org.bukkit.command.Command command, @NotNull String label, @NotNull String[] args) {
        if (this.onlyPlayer) {
            if (sender instanceof Player) {
                Player player = (Player) sender;
                execute(player, label, args);
                if (this.permission != null && !sender.hasPermission(this.permission)) {
                    sender.sendMessage(PluginLoader.INSTANCE.getMessageUtils().i18n("no-permission"));
                    return true;
                }
                execute(sender, label, args);
                return true;
            }
            sender.sendMessage(PluginLoader.INSTANCE.getMessageUtils().i18n("only-player"));
            return true;
        }
        return false;
    }

    @Nullable
    public List<String> onTabComplete(@NotNull CommandSender sender, org.bukkit.command.Command command, @NotNull String label, @NotNull String[] args) {
        return tabCompleter(sender, label, args).stream().filter(s -> {
            return s.toLowerCase(Locale.ROOT).startsWith(args[args.length - 1].toLowerCase(Locale.ROOT));
        }).toList();
    }

    @Override // cn.dg32z.lon.commands.Command
    public void execute(@NotNull CommandSender sender, @NotNull String label, @NotNull String[] args) {
    }

    @Override // cn.dg32z.lon.commands.Command
    public void execute(@NotNull Player sender, @NotNull String label, @NotNull String[] args) {
    }

    @Override // cn.dg32z.lon.commands.Command
    public List<String> tabCompleter(@NotNull CommandSender sender, @NotNull String label, @NotNull String[] args) {
        return new ArrayList();
    }
}
